@@ -189,9 +189,9 @@ class Service:
     def __init__(
         self,
         argparser: ArgumentParser,
-        cleanup: Callable[[], None] = lambda: None,
+        cleanup: Callable[[Any, Any], None],
     ):
-        self.cleanup: Callable[[], None] = cleanup
+        self.cleanup: Callable[[Any, Any], None] = cleanup
         argparser.add_argument("-name", type=str, required=True, help="Service name")
         argparser.add_argument("-log", type=str, required=True, help="Base dir for log")
         argparser.add_argument("-port", type=int, required=True, help="Service port")
@@ -222,7 +222,8 @@ class Service:
 
         def unregister_eureka(signal: Any, frame: Any):
             self.log.info("Cleanup before shutdown.")
-            self.cleanup()
+            if callable(self.cleanup):
+                self.cleanup(signal, frame)
             eureka_client.stop()
             sys.exit(0)
 
